@@ -204,7 +204,7 @@ class TestSample(SeededTest):
                 tune=5,
                 cores=2,
                 discard_tuned_samples=False,
-                start=[{"x": [10, 10]}, {"x": [-10, -10]}],
+                initvals=[{"x": [10, 10]}, {"x": [-10, -10]}],
                 random_seed=self.random_seed,
             )
         assert idata.warmup_posterior["x"].sel(chain=0, draw=0).values[0] > 0
@@ -226,7 +226,7 @@ class TestSample(SeededTest):
             tune = 50
             chains = 2
             start, step = pm.sampling.init_nuts(chains=chains, random_seed=[1, 2])
-            pm.sample(draws=2, tune=tune, chains=chains, step=step, start=start, cores=1)
+            pm.sample(draws=2, tune=tune, chains=chains, step=step, initvals=start, cores=1)
             assert step.potential._n_samples == tune
             assert step.step_adapt._count == tune + 1
 
@@ -403,12 +403,12 @@ def test_sample_find_MAP_does_not_modify_start():
 
         # make sure sample does not modify the start dict
         start = {"untransformed": 0.2}
-        pm.sample(draws=10, step=pm.Metropolis(), tune=5, start=start, chains=3)
+        pm.sample(draws=10, step=pm.Metropolis(), tune=5, initvals=start, chains=3)
         assert start == {"untransformed": 0.2}
 
         # make sure sample does not modify the start when passes as list of dict
         start = [{"untransformed": 2}, {"untransformed": 0.2}]
-        pm.sample(draws=10, step=pm.Metropolis(), tune=5, start=start, chains=2)
+        pm.sample(draws=10, step=pm.Metropolis(), tune=5, initvals=start, chains=2)
         assert start == [{"untransformed": 2}, {"untransformed": 0.2}]
 
 
@@ -474,7 +474,7 @@ def test_choose_chains(n_points, tune, expected_length, expected_n_traces):
 @pytest.mark.xfail(condition=(aesara.config.floatX == "float32"), reason="Fails on float32")
 class TestNamedSampling(SeededTest):
     def test_shared_named(self):
-        G_var = shared(value=np.atleast_2d(1.0), broadcastable=(True, False), name="G")
+        G_var = shared(value=np.atleast_2d(1.0), shape=(True, False), name="G")
 
         with pm.Model():
             theta0 = pm.Normal(
@@ -491,7 +491,7 @@ class TestNamedSampling(SeededTest):
             assert np.isclose(res, 0.0)
 
     def test_shared_unnamed(self):
-        G_var = shared(value=np.atleast_2d(1.0), broadcastable=(True, False))
+        G_var = shared(value=np.atleast_2d(1.0), shape=(True, False))
         with pm.Model():
             theta0 = pm.Normal(
                 "theta0",
@@ -1450,9 +1450,14 @@ def test_step_args():
         a = pm.Normal("a")
         idata0 = pm.sample(target_accept=0.5, random_seed=1410)
         idata1 = pm.sample(nuts={"target_accept": 0.5}, random_seed=1410 * 2)
+        idata2 = pm.sample(target_accept=0.5, nuts={"max_treedepth": 10}, random_seed=1410)
+
+        with pytest.raises(ValueError, match="`target_accept` was defined twice."):
+            pm.sample(target_accept=0.5, nuts={"target_accept": 0.95}, random_seed=1410)
 
     npt.assert_almost_equal(idata0.sample_stats.acceptance_rate.mean(), 0.5, decimal=1)
     npt.assert_almost_equal(idata1.sample_stats.acceptance_rate.mean(), 0.5, decimal=1)
+    npt.assert_almost_equal(idata2.sample_stats.acceptance_rate.mean(), 0.5, decimal=1)
 
     with pm.Model() as model:
         a = pm.Normal("a")
